@@ -6,6 +6,22 @@ import qondor
 logger = logging.getLogger('qondor')
 subprocess_logger = logging.getLogger('subprocess')
 
+# Python 2.6 compatibiltiy (see https://stackoverflow.com/a/13160748/9209944)
+if "check_output" not in dir( subprocess ): # duck punch it in!
+    logger.warning('Duck punching subprocess.check_output; suboptimal!')
+    def f(*popenargs, **kwargs):
+        if 'stdout' in kwargs:
+            raise ValueError('stdout argument not allowed, it will be overridden.')
+        process = subprocess.Popen(stdout=subprocess.PIPE, *popenargs, **kwargs)
+        output, unused_err = process.communicate()
+        retcode = process.poll()
+        if retcode:
+            cmd = kwargs.get("args")
+            if cmd is None:
+                cmd = popenargs[0]
+            raise subprocess.CalledProcessError(retcode, cmd)
+        return output
+    subprocess.check_output = f
 
 def _create_directory_no_checks(dirname, dry=False):
     """
@@ -125,7 +141,8 @@ def run_multiple_commands(cmds, env=None, dry=False):
         stderr = subprocess.STDOUT,
         env = env,
         bufsize = 1,
-        close_fds = True
+        close_fds = True,
+        encoding = 'utf8'
         )
 
     # Break on first error (stdin will still be written but execution will be stopped)
